@@ -7,6 +7,8 @@ from .accounts_api import AccountsApi
 from .authentication_api import AuthenticationApi
 from .billing_api import BillingApi
 from .bulk_envelopes_api import BulkEnvelopesApi
+from .bulk_process_data_api import BulkProcessDataApi
+from .bulk_process_data_send_api import BulkProcessDataSendApi
 from .cloud_storage_api import CloudStorageApi
 from .connect_api import ConnectApi
 from .custom_tabs_api import CustomTabsApi
